cis_config: obj_t Struct Reference

cis_config

Public Attributes | List of all members
obj_t Struct Reference

Obj structure. More...

`#include <ObjSerialize.h>`

## Public Attributes
int | nvert
| Number of vertices.
int | nface
| Number faces.
float ** | vertices
| X, Y, Z positions of vertices.
int ** | faces
| Indices of the vertices composing each face.
int ** | vertex_colors
| RGB colors of each vertex.
char | material [100]
| Material that should be used for faces.
int | ntexc
| Number of texture coordinates.
int | nnorm
| Number of normals.
float ** | texcoords
| Texture coordinates.
float ** | normals
| X, Y, Z direction of normals.
int ** | face_texcoords
| Indices of texcoords for each face.
int ** | face_normals
| Indices of normals for each face.

## Detailed Description

Obj structure.

The documentation for this struct was generated from the following file:

- /root/cis_interface/cis_interface/cis_interface/serialize/ObjSerialize.h